wsipipe.load.slides package
===========================

.. automodule:: wsipipe.load.slides
   :members:
   :undoc-members:
   :show-inheritance:

slide module
--------------------------------

.. automodule:: wsipipe.load.slides.slide
   :members:
   :undoc-members:
   :show-inheritance:

openslide module
------------------------------------

.. automodule:: wsipipe.load.slides.openslide
   :members:
   :undoc-members:
   :show-inheritance:

region module
---------------------------------

.. automodule:: wsipipe.load.slides.region
   :members:
   :undoc-members:
   :show-inheritance:

